function [A, B] = celest2earth(RA, DEC, GAST)

%CELEST2EARTH convert selestial to Earth-fixed coordinates
%
%SYNOPSIS
%   [A, B] = CELEST2EARTH(RA, DEC, GAST)
%
%   The position of a star in celestial coordinates is specified by 
%   right ascention and declination. In the Earth-fixed coordinate 
%   system it is specified by longitude and latitude.  
%
%INPUTS
%   RA   - Right ascention of the star [hours]
%   DEC  - Declination of the star [degrees]
%   GAST - Greenwich apparent sidereal time [hours]
%
%OUTPUTS
%   A - Latitude of the star [degrees]
%   B - Longitude of the star [degress]
%
%  Phi and Theta in Graven refer to latitude and longitude of a
%  location on Earth for which the star is in the zenith. That's why
%  it is called latitude and longitude. 
%  The declination of the star is the same as latitude.
%
%AUTHOR
%   Shantnu Desai (No longer part of the LV Collaboration)

% $Id: celest2earth.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

A = DEC;

% hour angle [hours]

HA = GAST - RA;

% longitude of the star [degress]

B = - HA * 15; 
B = mod(B + 180, 360) - 180;
