function y = gps2sidereal(x)

%GPS2SIDEREAL converts GPS time to sidereal time
%
%SYNOPSIS
%   Y = gps2sidereal(X)
%
%INPUT
%   X - GPS time in seconds (supports input vectors of GPS times)
%
%OUTPUT
%   Y - Greenwich apparent sidereal time in hours (y)
%
%AUTHOR
%  Shantanu Desai (No longer part of the LV Collaboration)

%  $Id: gps2sidereal.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% convert to integer in case of running in compiled matlab
x = strassign(x);

% calculate UTC
a = gps2utcCorr(x);

% calculate Julian day
JD = calen2jdn(a);

% calculate Greenwich apparent sidereal time (GAST) in hours
y = jdn2gast(JD);

return
