function gpsResult = gpssum(gpsTime1,gpsTime2)
%GPSSUM Sum time1+time2 in (S,NS) given two GPS times 
%
%SYNOPSIS
%   GPSRESULT = gpssum(GPSTIME1, GPSTIME2)
%
%INPUT
%   GPSTIME1    GPS time. Either integer seconds or struct with elements
%       sec, ns
%           sec: whole seconds
%           ns: residue in nano-seconds
%   GPSTIME2    GPS time to be subtracted from gpsTime1. Either integer
%       seconds or struct with elements sec, ns
%
%OUTPUT
%   GPSRESULT   Time difference gpsTime1 - gpsTime2. GPS time (struct
%       with elements sec, ns)
% 
% GPSTIME1 or GPSTIME2 may be 1-dimensional arrays. If both
% are arrays they must have same length. If input is an
% array, output is a struct array. 
%
% Sign convention if time < 0, .sec, .ns are both negative
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: gpssum.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

diffSec = 0;
diffNsec = 0;
% IF # input arguments is wrong
%   CREATE error
% EXIT
error(nargchk(2,2,nargin),'struct')

% IF T1 is a GPS structure
%	GET sec, ns from structure
% ELSE
%   CONVERT time to GPS structure
%	GET sec, ns from structure
% END
% IF T2 is a GPS structure
%	GET sec, ns from structure
% ELSE
%   CONVERT time to GPS structure
%	GET sec, ns from structure
% END
if(isstruct(gpsTime1))
	t1Sec = [gpsTime1(:).sec];
	t1NSec = [gpsTime1(:).ns];
else
	t1 = time2gps(gpsTime1);
    t1Sec = [t1(:).sec];
	t1NSec = [t1(:).ns];
end
if(isstruct(gpsTime2))
	t2Sec = [gpsTime2(:).sec];
	t2NSec = [gpsTime2(:).ns];
else
	t2 = time2gps(gpsTime2);
    t2Sec = [t2(:).sec];
	t2NSec = [t2(:).ns];
end

% FIND sum in whole seconds (pS), nanoseconds (pNS)
% - now correct for cases where the summed nanosecond > 1 second
% CALCULATE tNS = pNS - #nano seconds / second
% IF tNS > 0
%   pS  = pS + 1;
%   pNS = pNS - nsecPerSec;
% END

% find sums
pS = t1Sec + t2Sec;
pNS = t1NSec + t2NSec;

% Correct when # nanoseconds . 1 second
nsecPerSec = 1e9;
tNS = pNS - nsecPerSec;
sgn = (tNS >= 0);
pS = pS + sgn;
pNS = pNS - sgn*nsecPerSec;

gpsResult = struct('sec',num2cell(pS),'ns',num2cell(pNS));

return;
