function plotFile = savefigure(filePrefix,specFmt,plotRes)

%SAVEFIGURE - save current fig in fig,jpg,png,eps,tif formats
%
%SYNOPSIS
%   PLOTFILE = savefigure(FILEPREFIX,SPECFMT[,PLOTRES])
%
%INPUTS
%   FILEPREFIX - file name before extension
%   SPECFMT - [OPTIONAL]only save a particular format
%   PLOTRES - [OPTIONAL] resolution for saving plot
%             <default = 300 dpi>
%
%OUTPUT
%   PLOTFILE - cell-array of files created
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: savefigure.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% IF specific format was input
%   CLEAR all format flag
% ELSE
%   SET all format flag
% ENDIF
% IF plot resolution was input
%   SET resolution from input
% ELSE
%   SET to default resolution
% ENDIF
plotFile = [];
error(nargchk(1,3,nargin),'struct');
if(nargin > 1)
    specFmt = char(specFmt);
    if(isempty(specFmt) || ~ischar(specFmt))
        specAll = true;
        specFmt = [];
    else
        specAll = false;
    end
else
    specAll = true;
    specFmt = [];
end
DEF_RES = 300;
if(nargin > 2)
    plotRes = strassign(plotRes);
    if(isempty(plotRes) || ~isnumeric(plotRes))
        plotRes = DEF_RES;
    end
else
    plotRes = DEF_RES;
end
resStr = sprintf('-r%d',plotRes);

% GET handle to current figure
% CREATE main plot file name
% SAVE as MATLAB fig file
% IF saving all or just EPS
%   SAVE as EPS file
% ENDIF
figHandle = gcf;
figFile = sprintf('%s.fig',filePrefix);
fprintf('SAVEFIGURE: save plot as %s\n',figFile);
saveas(gcf,figFile);
plotFile = cell(1,1);
plotFile{1} = figFile;
nPlot = 1;
if(specAll || strcmp(specFmt,'eps'))
    epsFile = sprintf('%s.eps',filePrefix);
    print(resStr,'-depsc2',epsFile);
    nPlot = nPlot + 1;
    plotFile{nPlot} = epsFile;
end
% IF saving all or just PNG
%   SAVE as PNG file
% ENDIF
% IF saving all or just JPG
%   SAVE as JPEG file
% ENDIF
% IF saving all or just TIF
%   SAVE as TIFF file
% ENDIF
% CLEAR file handle
if(specAll || strcmp(specFmt,'tif') )
    tifFile = sprintf('%s.tif',filePrefix);
    print(resStr,'-dtiff',tifFile);
    nPlot = nPlot + 1;
    plotFile{nPlot} = tifFile;
end
if(specAll || strcmp(specFmt,'jpg'))
    jpgFile = sprintf('%s.jpg',filePrefix);
    print(resStr,'-djpeg',jpgFile);
    nPlot = nPlot + 1;
    plotFile{nPlot} = jpgFile;
end
if(specAll || strcmp(specFmt,'png'))
    pngFile = sprintf('%s.png',filePrefix);
    print(resStr,'-dpng',pngFile);
    nPlot = nPlot + 1;
    plotFile{nPlot} = pngFile;
end
delete(figHandle);
return
