function [varargout] = stairhist(varargin)

%STAIRHIST - Make stair-plot version of histogram
%
%OPTION 1:
%   SYNOPSIS
%      [FIGHAND,BINCNT,BINCTR] = stairhist(Y,YMIN,YMAX,NBINS) 
%
%   INPTUS
%       Y - data to be histogrammed
%       YMIN - min value of Y in histogram 
%       YMAX - max value of Y in histogram
%       NBINS - # of bins in histogram
%
%   OUTPUTS
%      FIGHAND - handle to figure object
%      BINCNT - # in each bin of histogram
%      BINCTR - center of each bin of histogram
%
%OPTION 2:
%   SYNOPSIS
%      [FIGHAND,STRAIRCNT,STAIREDGE] = stairhist(BINCNT,BINCTR) 
%
%   INPUTS
%      BINCNR - center of each bin in histogram
%      BINCTR - # in each bin of histogram
%
%   OUTPUTS
%      FIGHAND - handle to figure object
%      STAIRCNT - count at edge of stair
%      STAIREDGE - begining edge of stair
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: stairhist.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% IF raw data and limits was input
%   GET histogram with defined limits, bins
% ENDIF
% - output of 'limhist' is for bin centers. For a stair 
% plot we need the beginning of each bin
% GET bin spacing
% SET bin start = bin center - (bin spacing/2)
% ADD extra termination bin
% SET value in termination bin = previous bin
% CREATE stair plot
if(nargin == 4)
    Y = varargin{1};
    ymin = varargin{2};
    ymax = varargin{3};
    nbins = varargin{4};
    [binCnt,binCtr] = limhist(Y,ymin,ymax,nbins);
    if(nargout > 1)
        varargout{2} = binCnt;
        if(nargout > 2)
            varargout{3} = binCtr;
        end
    end
elseif(nargin == 2)
    binCtr = varargin{1};
    binCnt = varargin{2};
else
    msgId = 'stairhist:badInput';
    error(msgId,'%s: wrong number of inputs');
end
stairCnt = binCnt;
binSpace = binCtr(2) - binCtr(1);
stairEdge = binCtr - (binSpace/2);
numEdges = numel(stairEdge);
stairEdge(numEdges+1) = stairEdge(numEdges) + binSpace;
stairCnt(numEdges+1) = stairCnt(numEdges);
if(nargin == 2)
    if(nargout > 1)
        varargout{2} = stairCnt;
        if(nargout > 2)
            varargout{3} = stairEdge;
        end
    end
end
figHand = stairs(stairEdge,stairCnt,'r-','LineWidth',3);
if(nargout > 0)
    varargout{1} = figHand;
end
hold off;
return
