function result = norsegments(varargin);

%NORSEGMENTS Determine NOR of segment lists
%
% NORSEGMENTS returns the segment list corresponding to the NOR of the
% individual segment lists provided as arguments.  NORSEGMENTS allows
% an arbitrary number of input segment lists.
%
%SYNOPSIS
%   LIST = norsegments(LIST1, LIST2, ...);
%
%INPUTS
%   LINE1, LINE2, ... - Segments lists in the form of N-by-2 matrices,
%     formed from adjacent column-wise vectors of segment start and stop
%     times.
%
%   start1 stop1
%   start2 stop2
%   start3 stop3
%    ...    ...
%   startN stopN
%
% By definition, a segment is the half closed interval [start,stop).
% A segment is inclusive of the specified start time, but exclusive of
% the specified stop time.  The duration of a segment is defined as the
% difference between stop and start times.
%
% As an alternative, each segment may also be specified by its start time
% and duration.  However, the resulting segment list will be returned in
% terms of start and stop times.
%
%OUTPUT
%   LIST - NOR combination of input lists
%
% NORSEGMENTS also uses CULLSEGMENTS and MERGESEGMENTS to remove zero
% length segments and merge any overlapping or adjacent segments.
%
% NORSEGMENTS allows for semi-infinite and infinite segments, which may
% extend beyond the end of a data run.  To form the negated or of a list
% within the constraints of a data run, use NORSEGMENTS in conjunction
% with ANDSEGMENTS.
% 
% See also ANDSEGMENTS, NANDSEGMENTS, ORSEGMENTS, and NOTSEGMENTS.
%
%AUTHOR
%   Shourov K. Chatterji (No longer part of the LC Collaboration)

% $Id: norsegments.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% parse command line arguments
error(nargchk(1, Inf, nargin));

% determine intersection of the given lists
result = notsegments(orsegments(varargin{:}));

% return to calling function
return;
